import createAuth0Client from '@auth0/auth0-spa-js';
import { state } from './AuthState';
let client;
const DEFAULT_REDIRECT_CALLBACK = () => window.history.replaceState({}, document.title, window.location.pathname);
export async function loginWithPopup() {
    state.popupOpen = true;
    try {
        await client.loginWithPopup();
    }
    catch (e) {
        console.error(e);
    }
    finally {
        state.popupOpen = false;
    }
    const user = await client.getUser();
    state.user = user ? user : {};
    state.isAuthenticated = true;
}
export async function handleRedirectCallback() {
    state.loading = true;
    try {
        await client.handleRedirectCallback();
        const user = await client.getUser();
        state.user = user ? user : {};
        state.isAuthenticated = true;
    }
    catch (e) {
        state.error = e;
    }
    finally {
        state.loading = false;
    }
}
export async function loginWithRedirect(o) {
    return client.loginWithRedirect(o);
}
export async function getIdTokenClaims(o) {
    return client.getIdTokenClaims(o);
}
export async function getTokenSilently(o) {
    return client.getTokenSilently(o);
}
export async function getTokenWithPopup(o) {
    return client.getTokenWithPopup(o);
}
export function logout(o) {
    return client.logout(o);
}
export async function initClient(options, callbackRedirect) {
    client = await createAuth0Client({
        onRedirectCallback: DEFAULT_REDIRECT_CALLBACK,
        redirect_uri: `${window.location.origin}/login/callback`,
        ...options
    });
    try {
        // If the user is returning to the app after authentication
        if (window.location.search.includes('code=') &&
            window.location.search.includes('state=')) {
            // handle the redirect and retrieve tokens
            const { appState } = await client.handleRedirectCallback();
            // Notify subscribers that the redirect callback has happened, passing the appState
            // (useful for retrieving any pre-authentication state)
            callbackRedirect(appState);
        }
    }
    catch (e) {
        state.error = e;
    }
    finally {
        // Initialize our internal authentication state
        state.isAuthenticated = await client.isAuthenticated();
        const user = await client.getUser();
        state.user = user ? user : {};
        state.loading = false;
    }
}
//# sourceMappingURL=Auth.js.map