import { computed, inject, provide, ref } from 'vue';
import { getIdTokenClaims, getTokenSilently, getTokenWithPopup, handleRedirectCallback, initClient, loginWithPopup, loginWithRedirect, logout } from './Auth';
import { state } from './AuthState';
export const authPlugin = {
    isAuthenticated: computed(() => state.isAuthenticated),
    loading: computed(() => state.loading),
    user: computed(() => state.user),
    getIdTokenClaims,
    getTokenSilently,
    getTokenWithPopup,
    handleRedirectCallback,
    loginWithRedirect,
    loginWithPopup,
    logout
};
export const createAuth0 = async (options, callbackRedirect) => {
    await initClient(options, callbackRedirect);
};
function install(authPlugin) {
    return {
        install: (app) => {
            app.config.globalProperties.$auth = authPlugin;
            app.provide('auth', authPlugin);
        }
    };
}
export const installAuth0 = async (config) => {
    await createAuth0(config.options, config.callbackRedirect);
    return install(authPlugin);
};
const auth0Symbol = Symbol();
export async function provideAuth0(config) {
    const auth0 = ref(authPlugin);
    provide(auth0Symbol, auth0);
    await createAuth0(config.options, config.callbackRedirect);
}
export function useAuth0() {
    console.log(authPlugin);
    const auth0 = inject(auth0Symbol);
    console.log(auth0);
    return auth0;
}
//# sourceMappingURL=AuthPlugin.js.map